diff --git a/recman.cpp b/recman.cpp
index 33f0c54..5938c3d 100644
--- a/recman.cpp
+++ b/recman.cpp
@@ -192,19 +192,19 @@ Otherwise, the rec tree is re-created from currnet data.
     if (!recording) return 1;
     if (name) *name = cSv(recording->Name());
 
-    // check if recording is activ
-    std::string l_name(recording->FileName());
-    if (cRecordControl *rc = cRecordControls::GetRecordControl(l_name.c_str())) {
-        // local timer is activ
+    // check if recording is active
+    std::string fileName(recording->FileName());
+    if (cRecordControl *rc = cRecordControls::GetRecordControl(fileName.c_str())) {
+        // local timer is active
         if (cTimer *Timer = rc->Timer()) {
-            isyslog("live: deactivate local timer %s before delete of recording %s", *Timer->ToDescr(), name->c_str());
+            isyslog("live: deactivating local timer %s before deleting recording %s", *Timer->ToDescr(), name->c_str());
             Timer->OnOff();
             Timers->SetModified();
         }
     }
     else {
         // remote timer
-        cString TimerId = GetRecordingTimerId(l_name.c_str());
+        cString TimerId = GetRecordingTimerId(fileName.c_str());
         if (*TimerId) {
             int Id;
             char *RemoteBuf = NULL;
@@ -216,18 +216,18 @@ Otherwise, the rec tree is re-created from currnet data.
                     cTimer OldTimer = *Timer;
                     Timers->SetSyncStateKey(StateKeySVDRPRemoteTimersPoll);
                     cString ErrorMessage1;
-                    if (HandleRemoteTimerModifications(NULL, Timer, &ErrorMessage1)) { // delete activ timer on remote vdr
-                        isyslog("live: deactivate remote timer %s before delete of recording %s", *Timer->ToDescr(), name->c_str());
+                    if (HandleRemoteTimerModifications(NULL, Timer, &ErrorMessage1)) { // delete active timer on remote VDR
+                        isyslog("live: deactivating remote timer %s before deleting recording %s", *Timer->ToDescr(), name->c_str());
                         Timer->OnOff();
                         Timers->SetModified();
                         cString ErrorMessage2;
-                        if (!HandleRemoteTimerModifications(Timer, NULL, &ErrorMessage2)) {  // add deactived timer on remote vdr
-                            esyslog("live: add inactiv remote timer %s failed: %s", *Timer->ToDescr(), *ErrorMessage2);
+                        if (!HandleRemoteTimerModifications(Timer, NULL, &ErrorMessage2)) {  // add deactivated timer on remote VDR
+                            esyslog("live: adding inactive remote timer %s failed: %s", *Timer->ToDescr(), *ErrorMessage2);
                             return 2;
                         }
                     }
                     else {
-                        esyslog("live: delete of activ remote timer %s failed: %s", *Timer->ToDescr(), *ErrorMessage1);
+                        esyslog("live: deleting active remote timer %s failed: %s", *Timer->ToDescr(), *ErrorMessage1);
                         return 2;
                     }
                 }
@@ -235,7 +235,7 @@ Otherwise, the rec tree is re-created from currnet data.
         }
     }
     bool result = recording->Delete();
-    Recordings->DelByName(l_name.c_str());
+    Recordings->DelByName(fileName.c_str());
     return result?0:3;
   }
 
